Theming
=======

Custom css and js
-----------------

You can easily add css code and js code. You just need to create a custom.css or custom.js
in root directory.

Override template
-----------------

If you want to override a template, you need to create a "templates" directory and add your own template.

* home page : index.html
* gallery page: gallery-index.html

And to override sections you need to create a file in "templates/sections".

Create theme
------------

TODO
